@@ -42,7 +42,7 @@ def cmd_sample(parser, _, args):
         parser.error(DefinedErrorMessage.ERROR_SUPPORT_FORMAT)
 
     # Print the sample
-    root = 'kntgen_templates'
+    root = '../kntgen_templates'
     file_path = ''
     if template == SUPPORTED_TEMPLATES[0]:
         file_path = '/bloc/sample_input/sample_bloc'
@@ -52,6 +52,8 @@ def cmd_sample(parser, _, args):
         file_path = '/network/sample_input/sample_network'
     elif template == SUPPORTED_TEMPLATES[3]:
         file_path = '/ui/sample_input/kntgen_config'
+        # UI config only accept .yaml
+        extension = SUPPORTED_SOURCE_FORMAT[1]
     file_path = root + file_path + '.' + extension
     try:
         # Open file depends on extension
