@@ -1,7 +1,7 @@
-from constants import *
-from file_helpers import *
-from model.exception import *
-from pasteboard import *
+from kntgen.constants import *
+from kntgen.file_helpers import *
+from kntgen.model.exception import *
+from kntgen.pasteboard import *
 
 
 def handle_base_parser(parser, args, supported_sources=SUPPORTED_SOURCES):
